Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / invariant / __init__.py |  | 6 | 0 | 0 |  | 100.00%
src / invariant / cacheable.py |  | 33 | 1 | 0 |  | 96.97%
src / invariant / executor.py |  | 58 | 5 | 4 |  | 91.38%
src / invariant / expressions.py |  | 171 | 11 | 0 |  | 93.57%
src / invariant / graph.py |  | 73 | 1 | 2 |  | 98.63%
src / invariant / hashing.py |  | 42 | 0 | 0 |  | 100.00%
src / invariant / node.py |  | 33 | 1 | 0 |  | 96.97%
src / invariant / ops / __init__.py |  | 3 | 0 | 0 |  | 100.00%
src / invariant / ops / poly.py |  | 40 | 4 | 0 |  | 90.00%
src / invariant / ops / stdlib.py |  | 18 | 0 | 0 |  | 100.00%
src / invariant / params.py |  | 7 | 0 | 0 |  | 100.00%
src / invariant / protocol.py |  | 10 | 3 | 0 |  | 70.00%
src / invariant / registry.py |  | 64 | 9 | 0 |  | 85.94%
src / invariant / store / __init__.py |  | 5 | 0 | 0 |  | 100.00%
src / invariant / store / base.py |  | 22 | 3 | 0 |  | 86.36%
src / invariant / store / chain.py |  | 30 | 0 | 0 |  | 100.00%
src / invariant / store / codec.py |  | 155 | 0 | 0 |  | 100.00%
src / invariant / store / disk.py |  | 46 | 2 | 0 |  | 95.65%
src / invariant / store / memory.py |  | 30 | 1 | 0 |  | 96.67%
src / invariant / types.py |  | 30 | 1 | 3 |  | 96.67%
Total |  | 876 | 42 | 9 |  | 95.21%

No items found using the specified filter.